==> haskell-wuss-2.0.1.3-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.3
visibility:           public
id:                   wuss-2.0.1.3-9CKdURqSCKN4JNNN8XncAz
key:                  wuss-2.0.1.3-9CKdURqSCKN4JNNN8XncAz
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  8e7ee1aae77312d03c7544af9ac23575
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.3-9CKdURqSCKN4JNNN8XncAz
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.2-DOZ164n3eXa6RwsKiPrwUF exceptions-0.10.5
    network-3.1.4.0-EpGtkoqQTWdJPJAj8Thqiz
    websockets-0.12.7.3-KNcVtusQC5DAaWWgFwB3rJ

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wuss-2.0.1.3-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.3
visibility:           public
id:                   wuss-2.0.1.3-7xJxm6KUFGK50Sul6WrGco
key:                  wuss-2.0.1.3-7xJxm6KUFGK50Sul6WrGco
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  54a3822a444674aba82f8ca34a2564fb
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wuss-2.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.3-7xJxm6KUFGK50Sul6WrGco
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.2-8ldfHRXSaN5GMDr6RkcfUA exceptions-0.10.5
    network-3.1.4.0-L93bqt4J89t6uDPHvRPUpA
    websockets-0.12.7.3-LV1OGaXkZkgLv3TyUteSxV

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
